Update of /cvsroot/monetdb/pathfinder/compiler/include
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv5765/include
Modified Files:
algopt.h properties.h
Log Message:
-- Split up the required distribution value property as it
checked the order AND the consistent mapping of values at once.
The two new properties now separately check for the required order columns
and for columns whose values have to conform to a bijective mapping.
Index: algopt.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/algopt.h,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- algopt.h 11 Jan 2008 10:47:04 -0000 1.20
+++ algopt.h 14 Jan 2008 14:03:29 -0000 1.21
@@ -52,6 +52,7 @@
PFla_op_t * PFalgopt_key (PFla_op_t *root);
PFla_op_t * PFalgopt_mvd (PFla_op_t *root, unsigned int noneffective_tries);
PFla_op_t * PFalgopt_reqval (PFla_op_t *root);
+PFla_op_t * PFalgopt_rowrank (PFla_op_t *root);
PFla_op_t * PFalgopt_set (PFla_op_t *root);
PFla_op_t * PFalgopt_thetajoin (PFla_op_t *root);
Index: properties.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/properties.h,v
retrieving revision 1.32
retrieving revision 1.33
diff -u -d -r1.32 -r1.33
--- properties.h 11 Jan 2008 12:49:10 -0000 1.32
+++ properties.h 14 Jan 2008 14:03:29 -0000 1.33
@@ -70,8 +70,10 @@
unique values. */
req_bool_val_t req_bool_vals; /**< List of attributes with their
corresponding required values. */
- PFalg_att_t req_distr_cols; /**< List of columns whose values only
- have to have the same distribution. */
+ PFalg_att_t req_order_cols; /**< List of columns whose values need
+ to maintain the order. */
+ PFalg_att_t req_bijective_cols; /**< List of columns whose values have
+ to fulfill any bijective function. */
PFalg_att_t req_multi_col_cols; /**< List of columns that can be
split up into multiple columns. */
PFalg_att_t req_value_cols; /**< List of columns whose values are
@@ -446,10 +448,16 @@
bool PFprop_req_bool_val_val (const PFprop_t *prop, PFalg_att_t attr);
/**
* Test if @a attr is in the list of distribution columns
* in container @a prop
*/
-bool PFprop_req_distr_col (const PFprop_t *prop, PFalg_att_t attr);
+bool PFprop_req_order_col (const PFprop_t *prop, PFalg_att_t attr);
+
+/**
+ * Test if @a attr is in the list of bijective columns
+ * in container @a prop
+ */
+bool PFprop_req_bijective_col (const PFprop_t *prop, PFalg_att_t attr);
/**
* Test if @a attr is in the list of multi-col columns
-------------------------------------------------------------------------
Check out the new SourceForge.net Marketplace.
It's the best place to buy or sell services for
just about anything Open Source.
@@ -446,10 +448,16 @@
bool PFprop_req_bool_val_val (const PFprop_t *prop, PFalg_att_t attr);
/**
- * Test if @a attr is in the list of distribution columns
+ * Test if @a attr is in the list of order columns
* in container @a prop
*/
http://ad.doubleclick.net/clk;164216239;13503038;w?http://sf.net/marketplace
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins